@@ -10,9 +10,9 @@ __author__ = """
                 Diana Zaiceva <zaiceva@cs.karelia.ru>,
                 Mezhenin Artoym <mezhenin@cs.karelia.ru>,
                 Alexander Sannikov <sannikov@cs.karelia.ru>,
-                Ivan Galov <galov@cs.karelia.ru>
+                Kirill Germanov <kgermano@cs.karelia.ru>
              """
 __version__ = "0.3.1"
-__date__ = "$Date: 2010/10/13 $"
+__date__ = "$Date: 2010/11/04 $"
 __copyright__ = ""
 __license__ = "GPLv2"
