@@ -660,54 +660,79 @@ class Account(Structure):
     """
     #abstractmethod
     def send_comment (self, msg, parent, addit):
-    	"""
-	send comment to service 
-	
-	@param msg (Message) message for sending
-	@param parent (Message) parent message
-	@param addit (Dict) Additional data
-	@return None
-	"""
-	pass
+        """
+            send comment to service 
+            
+            @param msg (Message) message for sending
+            @param parent (Message) parent message
+            @param addit (Dict) Additional data
+            @return None
+        """
+        pass
+      
     #abstractmethod
     def del_comment (self, msg, addit):
-	"""
-	delete comment from service
-	
-	@param msg (Message) message for deleting
-	@param addit (Dict) Additional data
-	@return None
-	"""
-	pass
+        """
+            delete comment from service
+            
+            @param msg (Message) message for deleting
+            @param addit (Dict) Additional data
+            @return None
+        """
+        pass
     
     #abstractmethod
     def freeze_comment (self, msg, addit):
-      	"""
-	freeze/unfreeze comment
-	
-	@param msg (Message) message for freezing
-	@param addit (Dict) Additional data
-	@return None
-	"""
-	pass 
+        """
+            freeze/unfreeze comment
+            
+            @param msg (Message) message for freezing
+            @param addit (Dict) Additional data
+            @return None
+        """
+        pass 
     
     #abstractmethod 
     def screen_comment (self, msg, addit):
-	"""
-	screen/unscreen comment
-	
-	@param msg (Message) message for screening
-	@param addit (Dict) Additional data
-	@return None
-	"""
-	pass 
+        """
+            screen/unscreen comment
+            
+            @param msg (Message) message for screening
+            @param addit (Dict) Additional data
+            @return None
+        """
+        pass 
     
     #abstractmethod 
     def refresh_comments (self, addit):
-	"""
-	Sync comments with service
-	
-	@param addit (Dict) Additional data
-	@return None
-	"""
-	pass 
\ No newline at end of file
+        """
+            Sync comments with service
+            
+            @param addit (Dict) Additional data
+            @return None
+        """
+        pass 
+  
+  
+    def add_marked(self, msg,mark):
+        tmp = self.misc
+        msgm = msg.misc
+        msgm[mark+"_next"] = tmp[mark+"_first"]
+        msg.misc = msgm
+        tmp[mark+"_first"] = msg.id
+        self.misc = tmp
+        
+    def clean_tree(self, frozlist,screenlist):
+        tmp = self.misc
+        if 'frozen_first' not in tmp:
+            tmp['frozen_first']=None
+        if 'screened_first' not in tmp:
+            tmp['screened_first']=None       
+            
+        if tmp['frozen_first'] <> None:
+            tmp['frozen_first'] = Message(tmp['frozen_first']).clean_list_marked('frozen',frozlist)
+        if tmp['screened_first'] <> None:
+            tmp['screened_first'] = Message(tmp['screened_first']).clean_list_marked('screened',screenlist)
+        
+        self.misc=tmp
+        
\ No newline at end of file
