@@ -216,7 +216,7 @@ class Message(Structure):
         
         @return (list) list of Messages with comments to this message
         """
-        query = 'SELECT id FROM Messages WHERE parent=? ORDER BY date'
+        query = 'SELECT id FROM Messages WHERE parent=? ORDER BY custom_id'
         id_list = sql_driver.select_mcmd(query, (self.id,))
 
         comments = []
@@ -647,54 +647,127 @@ class Message(Structure):
     """
 
     def is_deleted(self):
-      	"""
-	Check comment for deleting
-	
-	@return True if comment is marked for deletind or False otherwise
-	"""
-	
-	if COMMENT <> self.type:
-	    raise TypeError("Illegal message type", "Message is not comment")
-	  
-	sm=self.misc
-	return sm['deleted']
-	    
+        """
+        Check comment for deleting
+        @return True if comment is marked for deletind or False otherwise
+        """
+        
+        if COMMENT <> self.type:
+            return False
+            #raise TypeError("Illegal message type", "Message is not comment")
+          
+        sm=self.misc
+        return sm['deleted']
+            
 
     def has_undeleted_childes(self):
-      	"""
-	Look for undeleted childes
-	
-	@return True if comment have undeleted childes or False otherwise
-	"""
-	if COMMENT <> self.type:
-	    raise TypeError("Illegal message type", "Message is not comment")
-	  
-	comm = self.get_comments()
-	for i in comm:
-	    if not i.is_deleted():
-		return True
-	    if i.has_undeleted_childes():
-		return True
-	return False
-	
-	
+        """
+        Look for undeleted childes
+        
+        @return True if comment have undeleted childes or False otherwise
+        """
+        if COMMENT <> self.type:
+            raise TypeError("Illegal message type", "Message is not comment")
+          
+        comm = self.get_comments()
+        for i in comm:
+            if not i.is_deleted():
+                return True
+            if i.has_undeleted_childes():
+                return True
+        return False
+        
+        
     def del_comment_local(self):
-      	"""
-	Delete comment sub-tree localy
-	
-	@return None
-	"""
-	if COMMENT <> self.type:
-	    raise TypeError("Illegal message type", "Message is not comment")
-	  
-	tmp = self.misc
-	tmp['deleted'] = True
-	self.misc = tmp
-	if self.has_undeleted_childes():
-	    self.text = '(Deleted Comment)'
-	    self.title = ''
-	else:
-	    par = self.parent
-	    self.del_msg_tree()
-	    if par.is_deleted():
-		par.del_comment_local()
+        """
+        Delete comment sub-tree localy
+        
+        @return None
+        """
+        if COMMENT <> self.type:
+            raise TypeError("Illegal message type", "Message is not comment")
+          
+        tmp = self.misc
+        tmp['deleted'] = True
+        self.misc = tmp
+        if self.has_undeleted_childes():
+            self.text = '(Deleted Comment)'
+            self.title = ''
+        else:
+            par = self.parent
+            if not par:
+                return
+            self.del_msg_tree()
+            if par.is_deleted():
+                par.del_comment_local()
+    
+    def clean_list_marked(self,  mark_type, newlist):  
+        if self.misc[mark_type] and (self.custom_id not in newlist):
+            self.__mark_childs(mark_type,False)
+            i = self.misc[mark_type+"_next"]
+            tmp = self.misc
+            del tmp[mark_type+"_next"]
+            self.misc = tmp
+            if i==None:
+                return None
+            return Message(i).clean_list_marked(mark_type,newlist)
+        else:
+            if self.misc[mark_type+"_next"]<>None:
+                tmp = self.misc
+                tmp[mark_type+"_next"] = Message(tmp[mark_type+"_next"]).clean_list_marked(mark_type,newlist)
+                self.misc = tmp
+            return self.id
+        
+        
+        
+    def have_frozen_parent(self):
+        return self._have_marked_parent('frozen',True)
+        
+    def have_screened_parent(self):
+        return self._have_marked_parent('screened',True)     
+        
+    def _have_marked_parent(self,mark,val):
+        if COMMENT <> self.type:
+            raise TypeError("Illegal message type", "Message is not comment")
+          
+        if self.parent.type == POST:
+            return False
+        
+        if self.parent.misc[mark]==val:
+            return True
+            
+        
+
+    
+    
+    def froze_childs(self):
+        self.__mark_childs('frozen',True)
+        
+    def unfroze_childs(self):
+        if self.have_frozen_parent():
+            raise TypeError("Illegal message type", "Message have frozen comments")
+        self.__mark_childs('frozen',False)
+    
+    def screen_childs(self):
+        self.__mark_childs('screened',True)
+        
+    def unscreen_childs(self):
+        if self.have_screened_parent():
+            raise TypeError("Illegal message type", "Message have screened comments")
+        self.__mark_childs('screened',False)    
+            
+      
+    def __mark_childs(self,field,flag):
+        if COMMENT <> self.type:
+            raise TypeError("Illegal message type", "Message is not comment")
+          
+        tmp = self.misc
+        tmp[field] = flag
+        self.misc = tmp 
+        
+        comm = self.get_comments()
+        for i in comm:
+            i.__mark_childs(field,flag)
+
+        
+    
\ No newline at end of file
