@@ -866,12 +866,12 @@ class LivejAccount(Account, Service):
     """
 
     def get_session (self):
-	"""
-	Generate session for using cookie autentification
-	
-	@return Cookie string
-	"""
-	self.connect()
+        """
+        Generate session for using cookie autentification
+        
+        @return Cookie string
+        """
+        self.connect()
         params = {
             'username': self.username,
             'ver': 1,
@@ -882,76 +882,80 @@ class LivejAccount(Account, Service):
         return lj_sess['ljsession']
 
     def send_comment (self, msg, parent, addit = None):
-	"""
-	send comment to livejournal
-	
-	@param msg (Message) message for sending
-	@param parent (Message) parent message
-	@param addit (Dict) unused
-	@return None
-	"""
-	"""
-	def lookup_for_root(mesg):
-	    if mesg.type == POST:
-		return mesg
-	    else:
-		lookup_for_root(mesg.parent)
-	  """
-	  
-	req = None
-	print "sending reach LiveJAccount"
-	try:
-	    misc = parent.misc
-	    if parent.type == POST:
-		ptid = 0
-		itemid = re.findall("\d+\.html$", parent.url)[0].split('.')[0]
-	    else:
-		ptid = parent.custom_id
-		mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND journal=? AND type=?",\
-		  (misc['parenttalkid'], self.id, POST))
-		print mid
-		itemid = re.findall("\d+\.html$", Message(mid).url)[0].split('.')[0]
-		#itemid = re.findall("\d+\.html$", lookup_for_root(Message(misc['parenttalkid'])).url)[0].split('.')[0]
-	  
-	    print "1"
-	    req = {
-		'parenttalkid': ptid,
-		'itemid': itemid,
-		'journal': parent.journal.username,
-		'usertype': 'user',
-		'userpost': self.username,
-		'password': self.passwd,
-		'do_login': '1',
-		'subject': msg.title,
-		'subjection':'none',
-		'body':msg.text,
-	    }
-	    print "2"
-	    req = urlencode(req)
-	except Exception, x:
-	    print  x
+        """
+        send comment to livejournal
+        
+        @param msg (Message) message for sending
+        @param parent (Message) parent message
+        @param addit (Dict) unused
+        @return None
+        """
+        """
+        def lookup_for_root(mesg):
+            if mesg.type == POST:
+                return mesg
+            else:
+                lookup_for_root(mesg.parent)
+          """
+          
+        req = None
+        print "sending reach LiveJAccount"
+        try:
+            misc = parent.misc
+            if parent.type == POST:
+                ptid = 0
+                itemid = re.findall("\d+\.html$", parent.url)[0].split('.')[0]
+            else:
+                ptid = parent.custom_id
+                mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND journal=? AND type=?",\
+                  (misc['parenttalkid'], self.id, POST))
+                print mid
+                itemid = re.findall("\d+\.html$", Message(mid).url)[0].split('.')[0]
+                #itemid = re.findall("\d+\.html$", lookup_for_root(Message(misc['parenttalkid'])).url)[0].split('.')[0]
+          
+            print "1"
+            req = {
+                'parenttalkid': ptid,
+                'itemid': itemid,
+                'journal': parent.journal.username,
+                'usertype': 'user',
+                'userpost': self.username,
+                'password': self.passwd,
+                'do_login': '1',
+                'subject': msg.title.encode( "utf-8" ),
+                'subjection':'none',
+                'body':msg.text.encode( "utf-8" ),
+            }
+            print "2"
+            req = urlencode(req)
+        except Exception, x:
+            print  x
         print req
         try:
-	    resp = urllib2.urlopen(urllib2.Request(LJ_SHORT+"/talkpost_do.bml",req))
-	    tmp = resp.readline()
-	    resp.close()
+            resp = urllib2.urlopen(urllib2.Request(LJ_SHORT+"/talkpost_do.bml",req))
+            tmp = resp.readlines()
+            resp.close()
+            #tfl = open("/home/user/log.html","w")
+            #for i in tmp:
+            #    tfl.write(i)
+            #tfl.close()
         except IOError, exc:
-	    print exc
+            print exc
             raise SocketExc(self, exc)
-	
+        
 
 
     def del_comment (self, msg, addit = None):
-	"""
-	delete comment from livejournal
-	
-	@param msg (Message) message for deleting
-	@param addit (Dict) must have 'delauthor' and 'delthread' keys only
-	  'delthread' - delete thread flag 1-yes, 0-no (default 0)
-	  'delauthor' - delete all by author flag 1-yes, 0-no (default 0) now unused
-	@return None
-	"""
-	##FIXME: deleting by author is not supported yet
+        """
+        delete comment from livejournal
+        
+        @param msg (Message) message for deleting
+        @param addit (Dict) must have 'delauthor' and 'delthread' keys only
+          'delthread' - delete thread flag 1-yes, 0-no (default 0)
+          'delauthor' - delete all by author flag 1-yes, 0-no (default 0) now unused
+        @return None
+        """
+        ##FIXME: deleting by author is not supported yet
         session = self.get_session()
         print msg.id
         print msg.title
@@ -964,82 +968,93 @@ class LivejAccount(Account, Service):
         r = urllib2.urlopen(req)
         page = r.readlines()
         try:
-	    dthr = addit['delthread']
-	except:
-	    dthr = 0
-	try:
-	    daut = addit['delauthor']
-	except:
-	    daut = 0
+            dthr = addit['delthread']
+        except:
+            dthr = 0
+        try:
+            daut = addit['delauthor']
+        except:
+            daut = 0
         self.__confirm(page,session,{'delauthor':daut,'delthread':dthr})
+        msg.del_comment_local()
         ##FIXME: add removing from DB!!!
         
     def freeze_comment (self, msg, addit = None):
-	"""
-	freeze/unfreeze comment from livejournal
-	
-	@param msg (Message) message for freezing
-	@param addit (Dict) unused
-	@return None
-	"""
+        """
+        freeze/unfreeze comment from livejournal
+        
+        @param msg (Message) message for freezing
+        @param addit (Dict) unused
+        @return None
+        """
         session = self.get_session()
         misc = msg.misc
         if misc['frozen']:
             mode = 'freeze'
         else:
             mode = 'unfreeze'
-	#FIXME dirty hack!!!
+        #FIXME dirty hack!!!
         req=urllib2.Request(LJ_SHORT+"/talkscreen.bml?mode=%s&journal=%s&talkid=%i" % (mode, msg.journal,\
                     int(str((int(msg.custom_id)) * 256 +5))),headers = {'Cookie': "ljsession=%s" %(session)})
         #FIXME end of dirty hack!!!
         r = urllib2.urlopen(req)
         page = r.readlines()
         self.__confirm(page,session,None)
+        
+        if misc['frozen']:
+            msg.unfroze_childs()
+        else:
+            msg.froze_childs()
         ##FIXME: add marking of frozen to misc
         ##NOTE: Fix frozen flag when get comments
         
     def screen_comment (self, msg, addit = None):
         """
-	screen/unscreen comment from livejournal
-	
-	@param msg (Message) message for screening
-	@param addit (Dict) unused
-	@return None
-	"""
+        screen/unscreen comment from livejournal
+        
+        @param msg (Message) message for screening
+        @param addit (Dict) unused
+        @return None
+        """
         session = self.get_session()
         misc = msg.misc
         if misc['screened']:
             mode = 'screen'
         else:
             mode = 'unscreen'
-	#FIXME dirty hack!!!
+        #FIXME dirty hack!!!
         req=urllib2.Request(LJ_SHORT+"/talkscreen.bml?mode=%s&journal=%s&talkid=%i" % (mode, msg.journal,\
                     int(str((int(msg.custom_id)) * 256 +5))),headers = {'Cookie': "ljsession=%s" %(session)})
         #FIXME end of dirty hack!!!
         r = urllib2.urlopen(req)
         page = r.readlines()
         self.__confirm(page,session,None)
+        
+        if misc['screened']:
+            msg.unscreen_childs()
+        else:
+            msg.screen_childs()
 
 
     def refresh_comments (self, callback, addit = None):
         """
-	update comments from livejournal
-	
-	@param addit (Dict) unused
-	@return None
-	"""
+        update comments from livejournal
+        
+        @param addit (Dict) unused
+        @return None
+        """
         cp = CommentProcessor()
         acc_misc = self.misc
         if acc_misc <> None and 'max_getted_comment' in acc_misc:
-	    cp.maxid = acc_misc['acc_misc']
-	    cp.current = acc_misc['acc_misc']-1
+            cp.maxid = acc_misc['acc_misc']
+            cp.current = acc_misc['acc_misc']-1
         session = self.get_session()
         #Gets metadata for all comments, get data only for new
         cp.current = -1
-	
-	once = True
+        
+        once = True
         while once or cp.maxid>cp.current:
-	    once = False
+            once = False
             req = urllib2.Request(LJ_SHORT+"/export_comments.bml?get=comment_meta&startid=%i"\
                       %(cp.current+1), headers = {'Cookie': "ljsession=%s"%(session)})
             rxml = urllib2.urlopen(req).read()
@@ -1047,21 +1062,24 @@ class LivejAccount(Account, Service):
             callback()
         
         try:
-	    cp.current = acc_misc['acc_misc']
-	except:
-	    cp.current = -1
-	 
-	while cp.maxid>cp.current: 
+            cp.current = acc_misc['acc_misc']
+        except:
+            cp.current = -1
+         
+        while cp.maxid>cp.current: 
             req = urllib2.Request(LJ_SHORT+"/export_comments.bml?get=comment_body&startid=%i"\
                       % (cp.current+1), headers = {'Cookie': "ljsession=%s"%(session)})
             rxml = urllib2.urlopen(req).read()
             cp.feeddata(rxml)
             callback()
-	try:
-	    _i = acc_misc['acc_misc']
-	except:
-	    acc_misc['acc_misc'] = 0
-	    self.misc = acc_misc
+            
+        try:
+            _i = acc_misc['acc_misc']
+        except:
+            acc_misc['acc_misc'] = 0
+        finally:
+            self.misc = acc_misc
+            
         self.__savecomments(cp.changeset, cp.umap)
         acc_misc['acc_misc'] = cp.maxid
         self.misc = acc_misc
@@ -1069,125 +1087,196 @@ class LivejAccount(Account, Service):
         
         
 
+
         
     def __savecomments (self, changeset, umap):
         """
-	update comments in DB by changeset
-	
-	@param changeset (List of Dict) unused
-	@param umap (List of Dict) unused
-	@return None
-	"""
-        ##FIXME: Needs implementation
-        kl = changeset.keys()
-        print changeset
-        kl.sort()
-	for i in kl:
-	    if changeset[i]['state']=='A':
-	        #comment yet added
-	        print i
-	        print self.misc
-	        if i <= self.misc['acc_misc']:
-		    continue
-		print changeset[i]
-		comment = Message()
-		comment.custom_id = i
-                comment.type = COMMENT
-		if changeset[i].get('subject',None)==None:
-		    changeset[i]['subject'] = '(No Subject)'
-		comment.title = changeset[i]['subject']
-		comment.date = changeset[i]['date']
-		comment.text = string.replace(changeset[i]['body'], "\n", "<br/>")
-		
-		comment.misc = {'parenttalkid':changeset[i]['jitemid'],'frozen':False,'screened':False,
-			      'deleted':False}
-		if self.group:
-		    raise TypeError("Illegal Account type", "Account is group. Me cant get comments for group,"\
-			      "so this is an error")
-		
-		
-		print sql_driver.select_mcmd("SELECT id, journal, custom_id FROM Messages")
-                #acc_id = sql_driver.select_cmd("SELECT id FROM Accounts WHERE username=? AND service_id=?",\
-		#  (umap[changeset[i]['posterid']], self.service_id))
-		  
-		poster = Account.register(type(self), umap[changeset[i]['posterid']])
-		comment.poster = poster
-		comment.journal = self
-		#.....
-		par_id = changeset[i]['parentid']
-		if par_id == 0:
-		    par_id = changeset[i]['jitemid']
-                print i
-                print self.id
-                print par_id
-                sql_driver._db.commit()
-		mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND journal=?",\
-		  (par_id, self.id))
-		par_msg = Message(mid)
-		
-		mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND journal=?",\
-		  (changeset[i]['jitemid'], self.id))
-		jitem_msg = Message(mid)
-		par_msg.add_comment(comment, jitem_msg)
-		
-		
-	    elif changeset[i]['state']=='D':
-	        try:
-		    print "deleting" 
-		    print "SELECT id FROM Messages WHERE custom_id=%d AND type=%d AND journal=%d"\
-		              %(i, COMMENT, self.id)
-		    mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND type=? AND journal=?",\
-		              (i, COMMENT, self.id))
-		    print mid
-		    scr_msg = Message(mid)
-		    print scr_msg
-		    scr_msg.del_comment_local(self)
-		except Exception,ex:
-		    print "error"+ str(ex)
-		    
-	    elif changeset[i]['state']=='F':
-		try:
-		    mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND type=? AND journal=?",\
-			(i, COMMENT, self.id))
-		    scr_msg = Message(mid)
-		    tmisc = scr_msg.misc
-		    tmisc['frozen'] = not tmisc['frozen']
-		    scr_msg.misc = tmisc
-		except:
-		    pass
-		    
-	    elif changeset[i]['state']=='S':
-		try:
-		    mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND type=? AND journal=?",\
-			(i, COMMENT, self.id))
-		    scr_msg = Message(mid)
-		    tmisc = scr_msg.misc
-		    tmisc['screened'] = not tmisc['screened']
-		    scr_msg.misc = tmisc
-		except:
-		    pass
-	    else:
-		raise Warning("Illegal XML","Illegal XML recieved from LiveJournal")
-	      
+        update comments in DB by changeset
+        
+        @param changeset (List of Dict) unused
+        @param umap (List of Dict) unused
+        @return None
+        """
+        #kl = changeset.keys()
+        #print changeset
+        #kl.sort()
+        
+        #list of changes data
+        changelist = {}
+        #list of deleted, frozen and screened comments
+        deleted = []
+        frozen = []
+        screened = []
+        
+        #function  for lookup parent of message in DB           
+        def __is_parent_added(comment):
+            try:
+                par_id = comment['parentid']
+                if par_id == 0:
+                    par_id = comment['jitemid']
+                mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND journal=?",\
+                        (par_id, self.id))
+                return True
+            except:
+                return False
+        
+        #fill list of id of deleted, frozen, screened post
+        def ___split_changeset():     
+            for i in changeset:
+                if changeset[i]['state']=='D':
+                    deleted.append(i)
+                elif changeset[i]['state']=='S':
+                    screened.append(i)
+                elif changeset[i]['state']=='F':
+                    frozen.append(i)
+                    
+        #generate message by custom_id
+        def __msg_by_cid(cid, mtype=COMMENT):
+
+            try:
+                mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND journal=? AND type=?",\
+                                (str(cid), str(self.id), str(mtype)))
+                msg = Message(mid)
+                return (msg, False)
+            except:
+                msg = Message()
+                msg.type = COMMENT
+                msg.custom_id = cid
+                msg.journal = self              
+                return (msg, True)
+            
+            
+        
+        #generate lists
+        ___split_changeset()
+       
+        #add all comments from changeset
+        while len(changeset)>0:
+            #resolve deps
+            
+            added = []
+            for i in changeset:
+            
+                #get or create message
+                comment, isnew = __msg_by_cid(i)
+                #if message is new add data
+                if isnew:
+                    
+                    comment.title = changeset[i]['subject']
+                    comment.date = changeset[i]['date']
+                    comment.text = string.replace(changeset[i]['body'], "\n", "<br/>")
+                    comment.misc = {'parenttalkid':changeset[i]['jitemid'],'frozen':False,'screened':False,
+                                      'deleted':False}
+                    comment.poster = Account.register(type(self), umap[changeset[i]['posterid']])
+                
+                    #add message to tree of comments
+                    par_id = changeset[i]['parentid']
+                    mtp = COMMENT
+                    if par_id == 0:
+                        print 'jitemid'
+                        par_id = changeset[i]['jitemid']
+                        mtp = POST
+                    par_msg, isnew = __msg_by_cid(par_id, mtp)
+                    
+                    if isnew:
+                        par_msg.del_msg_tree()
+                        comment.del_msg_tree()
+                        continue
+                    if (comment.date == None) or (comment.date == ""):
+                        comment.date = par_msg.date
+                        #raise LookupError("Message not founded in DB", "Trying to comment not existing message")
+                      
+                    jitem_msg, isnew = __msg_by_cid(changeset[i]['jitemid'],POST)
+                    print jitem_msg.id
+                    print jitem_msg.custom_id
+                    print jitem_msg.journal.id
+                    print jitem_msg.type
+                    if isnew:
+                        jitem_msg.del_msg_tree()
+                        raise LookupError("Message not founded in DB", "Trying to comment not existing message")
+                    
+                    par_msg.add_comment(comment, jitem_msg)
+                    sql_driver._db.commit()
+                added.append(i)
+            print added
+            for i in added:
+                #delet alredy exists comments
+                del changeset[i]
+            if len(added)==0:
+                break
+            #print '==========================================='
+            #print len(changeset)
+            #print '===========================================' 
+            #if st_len < 0:
+            #   raise LookupError("Comment tree corrupted", "Some comments haven't parents")
+        
+        self.clean_tree(frozen,screened)
+        
+        #froze messages
+        for i in frozen:
+            comment, isnew = __msg_by_cid(i)
+            if isnew:
+                comment.del_msg_tree()
+                continue
+                #raise LookupError("Message not founded in DB", "Trying to froze not existing message")
+            
+            misc = comment.misc
+            misc['frozen'] = True
+            comment.misc = misc
+            #TODO: add to message class
+            comment.froze_childs()
+            self.add_marked(comment,'frozen')
+            
+        #screen messages
+        for i in screened:
+            comment, isnew = __msg_by_cid(i)
+            if isnew:
+                comment.del_msg_tree()
+                continue
+                #raise LookupError("Message not founded in DB", "Trying to screen not existing message")
+            
+            misc = comment.misc
+            misc['screened'] = True
+            comment.misc = misc
+            #TODO: add to message class
+            comment.screen_childs()
+            self.add_marked(comment,'screened')
+            
+        #delete messages
+        for i in deleted:
+            comment, isnew = __msg_by_cid(i)
+            if isnew:
+                comment.del_msg_tree()
+                continue
+                #raise LookupError("Message not founded in DB", "Trying to delete not existing message")
+            
+            misc = comment.misc
+            misc['deleted'] = True
+            comment.misc = misc
+            comment.del_comment_local()
+
+        
     def __confirm (self, page, session=None, uparams=None):
-	"""
-	Confirm operation. (get form from HTML-page, fill it and send)
-	
-	@param page (string list) HTML-page source
-	@param session (string) Cookie string for auhtentification (Default None)
-	@param uparams (dict) additional params for form (Default None)
-	@return None
-	"""
-	def strsinstr(srcstr, pats):
-	    for i in pats:
-		if string.find(srcstr, i)>=0:
-		    return True
-	    return False  
+        """
+        Confirm operation. (get form from HTML-page, fill it and send)
+        
+        @param page (string list) HTML-page source
+        @param session (string) Cookie string for auhtentification (Default None)
+        @param uparams (dict) additional params for form (Default None)
+        @return None
+        """
+        def strsinstr(srcstr, pats):
+            for i in pats:
+                if string.find(srcstr, i)>=0:
+                    return True
+            return False  
+            
+            
         if session:
             headers = {'Cookie':"ljsession=%s" %(session)}
         else:
             headers = None
-	# Finds useful content
+        # Finds useful content
         pat = ("<!-- your content here -->","<!-- Content -->")
         while not strsinstr(page.pop(0), pat):
             pass
@@ -1195,21 +1284,21 @@ class LivejAccount(Account, Service):
         pat = ("<!-- /content -->","<!-- End \#content -->")
         while not strsinstr(page.pop(), pat):
             pass
-	  
-	#Look for form in HTML-page
+          
+        #Look for form in HTML-page
         html_data = string.join(page)
         parcer = CHTMLParser()
         parcer.feed(html_data)
-	#Update params by user's params
+        #Update params by user's params
         params = parcer.params
         if uparams:
             params.update(uparams)
-	#send request
-	print "============================="
-	print parcer.request
-	print urllib.urlencode(params)
-	print headers
-	print "============================="
+        #send request
+        print "============================="
+        print parcer.request
+        print urllib.urlencode(params)
+        print headers
+        print "============================="
         req=urllib2.Request(parcer.request, urllib.urlencode(params), headers=headers)
         print req
         r = urllib2.urlopen(req)
