@@ -44,58 +44,65 @@ class CommentProcessor:
 
         
     def feedmeta(self, rawxml):
-	"""
+        """
         Process new part of XML with meta-data recieved from livejournal.
 
         @param rawxml (string) part of XML
         @return False if processing is finished or True otherwise
         """
-	print rawxml
+        #print rawxml
         tdom = xml.dom.minidom.parseString(rawxml)
-	try:
-	    if self.maxid==0:
-		self.maxid = int(tdom.getElementsByTagName("maxid")[0].childNodes[0].data)
-	except x:
-	    print x
-	    	
-	try:
-	    users = tdom.getElementsByTagName("usermap")
-	    for user in users:
-		self.umap[int(user.getAttribute('id'))] = user.getAttribute('user')
-	except:
-	    pass
-	  
-	changes = tdom.getElementsByTagName("comment")
-	for change in changes:
-            try:
-                posterid = int(change.getAttribute('posterid'))
-            except:
-                posterid = 0
+        
+        #get maxid
+        try:
+            if self.maxid==0:
+                self.maxid = int(tdom.getElementsByTagName("maxid")[0].childNodes[0].data)
+        except x:
+            print x
+            
+        #generate usermap
+        try:
+            users = tdom.getElementsByTagName("usermap")
+            for user in users:
+                self.umap[int(user.getAttribute('id'))] = user.getAttribute('user')
+        except:
+            pass
 
-            try:
-                state =change.getAttribute('state')
-                if state =='':
-            	    state = 'A'
-            except:
-                state = 'A'
+        #generate template for changeset
+        changes = tdom.getElementsByTagName("comment")
+        for change in changes:
+                try:
+                    posterid = int(change.getAttribute('posterid'))
+                except:
+                    posterid = 0
 
-            try:
-                parentid = int(change.getAttribute('parentid'))
-            except:
-                parentid = 0
+                try:
+                    state =change.getAttribute('state')
+                    if state =='':
+                        state = 'A'
+                except:
+                    state = 'A'
 
-            try:
-                jitemid = int(change.getAttribute('jitemid'))
-            except:
-                jitemid = 0
-            cid = int(change.getAttribute('id'))
-            self.changeset[cid] = {'posterid':posterid, 'state':state, 'parentid':parentid, 'jitemid':jitemid}
-            if cid > self.current:
-                self.current = cid
-            print self.changeset[cid]
+                try:
+                    parentid = int(change.getAttribute('parentid'))
+                except:
+                    parentid = 0
+
+                try:
+                    jitemid = int(change.getAttribute('jitemid'))
+                except:
+                    jitemid = 0
+                cid = int(change.getAttribute('id'))
+                self.changeset[cid]={'posterid':posterid, 'state':state, 'parentid':parentid, 'jitemid':jitemid}
+                if self.changeset[cid]['state']=='D':
+                    self.changeset[cid]['subject'] = "-"
+                    self.changeset[cid]['body'] = "(Deleted comment)"
+                    self.changeset[cid]['date'] = ""
+                if cid > self.current:
+                    self.current = cid
 
     def feeddata(self, rawxml):
-	"""
+        """
         Process new part of XML with meta-data recieved from livejournal.
 
         @param rawxml (string) part of XML
@@ -105,31 +112,24 @@ class CommentProcessor:
         tdom = xml.dom.minidom.parseString(rawxml)
 
         comments = tdom.getElementsByTagName("comment")
+        # fill changeset by  ids and existed data
         for comment in comments:
             cid = int(comment.getAttribute('id'))
+            cur = 0
+            self.changeset[cid]['date'] = ""
+            self.changeset[cid]['subject'] = ""
+            self.changeset[cid]['date'] = ""
+            self.changeset[cid]['body']=""
             try:
                  self.changeset[cid]['parentid']= int(comment.getAttribute('parentid'))            
             except:
                  pass
+
             try:
                  self.changeset[cid]['jitemid']= int(comment.getAttribute('jitemid'))   
             except:
                  pass
 
-
-            """
-            for i in self.changeset[cid].keys():
-                print i
-                print self.changeset[cid][i]
-                print comment.getAttribute(i)
-                try:
-                    try:
-                        self.changeset[cid][i] = int(comment.getAttribute(i))
-                    except:
-                        self.changeset[cid][i] = comment.getAttribute(i)
-                except:
-                    pass
-            """
             if self.changeset[cid]['state']=='A':
                 self.changeset[cid]['body'] = comment.getElementsByTagName("body")[0].childNodes[0].data
                 self.changeset[cid]['date'] = comment.getElementsByTagName("date")[0].childNodes[0].data
@@ -137,9 +137,19 @@ class CommentProcessor:
                     self.changeset[cid]['subject'] = comment.getElementsByTagName("subject")[0].childNodes[0].data
                 except:
                     self.changeset[cid]['subject'] = None
-	    #print self.changeset[cid]
-	    if cid>self.current:
-		self.current = cid
+
+            if self.changeset[cid]['state']=='D':
+                self.changeset[cid]['subject'] = "-"
+                self.changeset[cid]['body'] = "(Deleted comment)"
+        # add empty fields for deleted and scrreend comments      
+
+        #print self.changeset[cid]
+
+        #update number of yet updated comments
+        if cid>self.current:
+            self.current = cid
+	    
+	    
 	    
 class CHTMLParser(HTMLParser):
 
