@@ -90,7 +90,7 @@ class HomePage(MainWindow):
         """
 
         #def_acc = main_prof.def_account
-        print def_acc
+        #print def_acc
         info = self.tr("<h2>Personal info:</h2><br>")
         if def_acc.nick:
             #print def_acc.nick
