@@ -318,7 +318,6 @@ class ListMyPosts(MainWindow):
             else:
                 return friend.get_posts()
         else:
-            print "get filters"
             return self.filter_list
 
 
@@ -343,6 +342,10 @@ class ListMyPosts(MainWindow):
                                      QtGui.QDialogButtonBox.ActionRole)
         self.text_button = but_box.addButton(self.tr("By content"),
                                       QtGui.QDialogButtonBox.ActionRole)
+        self.poster_button.setMinimumWidth(350)
+        self.date_button.setMinimumWidth(350)
+        self.read_button.setMinimumWidth(350)
+        self.text_button.setMinimumWidth(350)
 
         self.find_in_found = QtGui.QCheckBox(self.tr("Search in results"))
         cancel_button = self.f_dial.addButton(QtGui.QMessageBox.Abort)
@@ -444,7 +447,7 @@ class ListMyPosts(MainWindow):
             else:
                 for acc in main_prof.accounts:
                     temp_list.extend(self.ui_filter_msg(field, first_value, filt_list = self.filter_list, acc_id = acc.id))
-            print self.filter_list
+            #print self.filter_list
             self.filter_list = temp_list
             #refresh displayed list of posts
             self.flag_is_filter = True
@@ -468,7 +471,7 @@ class ListMyPosts(MainWindow):
             else:
                 for acc in main_prof.accounts:
                     temp_list.extend(self.ui_filter_msg(field, first_value, filt_list = self.filter_list, acc_id = acc.id))
-            print self.filter_list
+            #print self.filter_list
             self.filter_list = temp_list
             #refresh displayed list of posts                                                                                                       
             self.flag_is_filter = True
@@ -495,7 +498,7 @@ class ListMyPosts(MainWindow):
                 for acc in main_prof.accounts:
                     temp_list.extend(self.ui_filter_msg(field, first_value, filt_list = self.filter_list, acc_id = acc.id))
             self.filter_list = temp_list
-            print self.filter_list
+            #print self.filter_list
             #refresh displayed list of posts                                                                                                               
             self.flag_is_filter = True
             self.end_refresh()
@@ -554,7 +557,7 @@ class ListMyPosts(MainWindow):
                     for acc in main_prof.accounts:
                         temp_list.extend(self.ui_filter_msg(field, first_value, second_value, filt_list = self.filter_list, acc_id = acc.id))
                 self.filter_list = temp_list           
-                print self.filter_list
+                #print self.filter_list
                 self.flag_is_filter = True
                 self.end_refresh()
                 return
