@@ -18,6 +18,10 @@ import sys
 from PyQt4 import QtCore
 from PyQt4 import QtGui
 from ldm.Profile import main_prof
+from ldm.Account import *
+from services.LivejAccount import LivejAccount
+
+OUR_JOURNAL = "scribo_journal"
 
 class MainWindow(QtGui.QMainWindow):
     """
@@ -145,11 +149,10 @@ class MainWindow(QtGui.QMainWindow):
             author = mes.poster
             icon = ""
             if author:
-               text = text.decode('utf8') + "  (" + str(author.username).decode('utf8') + ")"
+               text = text + "  (" + author.username + ")"
                icon = author.get_icon()
                if not icon:
                    icon = ""
-            print text
             new_item = QtGui.QListWidgetItem(QtGui.QIcon(QtCore.QString(icon)),
                                              text,
                                              list_widget)
@@ -207,17 +210,61 @@ class MainWindow(QtGui.QMainWindow):
         @return
         """
         from About import __version__ as ver
-        QtGui.QMessageBox.about(self, self.tr("About Scribo"),
-                                self.tr("A mobile multiblog client."\
+        self.dial_about = QtGui.QMessageBox(self)
+        self.dial_about.setWindowTitle(self.tr("About Scribo"))
+        self.dial_about.setIcon(QtGui.QMessageBox.Information)
+        
+        label_about =  QtGui.QLabel(self.tr("A mobile multiblog client."\
                                         " \n Version: " + ver+
-                                        "\n More information you can get from README file."))
+                                        "\n More information you can get from README file.\n"))  
+        #label_about.setBackgroundRole(QtGui.QPalette.AlternateBase)  
+        #label_about.setForegroundRole(QtGui.QPalette.Text)
+                                   
+        label_friend = QtGui.QLabel(self.tr("You can add us to your friends to leave your feedback"))
+        self.push_fr = QtGui.QPushButton(self.tr("Add friend"), self.dial_about)
+        self.push_fr.setMinimumWidth(350)
+        self.connect(self.push_fr, QtCore.SIGNAL("clicked()"), self.add_us_friend)
+        self.dial_about.layout().addWidget(label_about, 0, 0, 1, 2, QtCore.Qt.AlignLeft) 
+        self.dial_about.layout().addWidget(label_friend, 1, 0, 1, 2, QtCore.Qt.AlignLeft)  
+        self.dial_about.layout().addWidget(self.push_fr, 2, 0, QtCore.Qt.AlignLeft)
+        
+                                        
+        cancel_button = self.dial_about.addButton(QtGui.QMessageBox.Abort)
+        cancel_button.hide()
+         
+        self.dial_about.exec_()
+        if self.dial_about.clickedButton() == cancel_button:
+            return
+
+    def add_us_friend(self):
+        flag_add_us_fr = False
+        for acc in main_prof.accounts:
+            if type(acc) == LivejAccount:
+                friend_acc = Account.register(LivejAccount, OUR_JOURNAL)
+                acc.add_friend(friend_acc)
+                flag_add_us_fr = True
+                break
+        if flag_add_us_fr:
+             QtGui.QMessageBox.information(self,
+                              self.tr("Scribo"),
+                              self.tr("Friend is added"),
+                              QtGui.QMessageBox.Ok)
+             self.push_fr.setDisabled(True)
+        else:
+             QtGui.QMessageBox.warning(self,
+                              self.tr("Scribo"),
+                              self.tr("We wasn't added to the friend. May be, we\
+                              don't have LiveJournal account, then you can adds it."),
+                              QtGui.QMessageBox.Ok)
+             
+ 
     def show_warning(self, exc):
         """  
         error message
         @param exc - exception
         @return
         """
-
+        print type(exc)
         QtGui.QMessageBox.warning(self,
                                   self.tr("Scribo"),
                                   exc.to_html(),
@@ -382,10 +429,10 @@ class MainWindow(QtGui.QMainWindow):
         bold_font.setBold(True)
         self.exit_act.setFont(bold_font)
 
-        self.about_act = QtGui.QAction(self.tr("&About"), self)
+        self.about_act = QtGui.QAction(QtCore.QCoreApplication.translate("MainWindow","About"), self)
         self.connect(self.about_act, QtCore.SIGNAL("triggered()"), self.about)
         
-        self.settings_act = QtGui.QAction(self.tr("&Settings"), self)
+        self.settings_act = QtGui.QAction(self.tr("Settings"), self)
         self.connect(self.settings_act, QtCore.SIGNAL("triggered()"), self.settings_change)
 
         self.draft_act = QtGui.QAction(self.tr("Drafts"), self)
@@ -401,9 +448,9 @@ class MainWindow(QtGui.QMainWindow):
         self.main_menu = self.menuBar().addMenu(self.tr("&Menu"))
         self.main_menu.addAction(self.new_act)
         self.main_menu.addAction(self.manage_act)
-        self.main_menu.addAction(self.about_act)
         self.main_menu.addAction(self.draft_act)
         self.main_menu.addAction(self.settings_act)
+        self.main_menu.addAction(self.about_act)
         self.main_menu.addSeparator()
         self.main_menu.addAction(self.exit_act)
 
