@@ -16,7 +16,7 @@ from PyQt4 import QtGui
 #from HomePage import home_window
 from MainWindow import *
 from ToolbarWindow import ToolbarWindow
-
+from ldm.Message import DRAFT, POST
 __author__ = "Diana Zaiceva <zaiceva@cs.karelia.ru>"
 __version__ = "$Revision: 0.2 $"
 __date__ = "$Date: 2010/06/26 $"
@@ -82,6 +82,8 @@ class RepeatPost(MainWindow):
         self.all_acc = []
         list_acc = main_prof.accounts
         index = 0
+        if self.mes.type == DRAFT:
+            draft_author = self.mes.poster
         for acc in list_acc:
             self.all_acc.append(acc)
             path_icon = acc.get_icon()
@@ -105,7 +107,8 @@ class RepeatPost(MainWindow):
             child_login.setData(1, QtCore.Qt.CheckStateRole, QtCore.QVariant(QtCore.Qt.Unchecked))
             child_login.setData(0, QtCore.Qt.UserRole, QtCore.QVariant(index))
             index = index + 1
-
+            if draft_author and acc == draft_author:
+                child_login.setSelected(True)   
             #if login has group...
             groups = acc.get_journals()
             if groups:
@@ -126,6 +129,7 @@ class RepeatPost(MainWindow):
         tree_widget.insertTopLevelItems(0, accounts)
         self.connect(tree_widget,
                       QtCore.SIGNAL("itemActivated (QTreeWidgetItem *,int)"), self.click_item)
+       
         return tree_widget
 
 
@@ -182,6 +186,7 @@ class RepeatPost(MainWindow):
                                                 self.tr("Post was sent"),
                                                 QtGui.QMessageBox.Yes)
             self.parent.sending_post = True
+            self.mes.del_msg_tree()
             super(RepeatPost, self).home_window()
 
     def home_window(self):
