@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """
  @file: ViewMessage.py
   File is a part of Scribo Project
@@ -57,8 +56,8 @@ class ViewMessage(MainWindow):
         if key > len(self.list) - 2:
             self.down_act.setDisabled(True)
         #check out JS scripts
-        #QWebSettings.globalSettings().setAttribute(QWebSettings.JavascriptEnabled,
-        #                                           False)
+        QWebSettings.globalSettings().setAttribute(QWebSettings.JavascriptEnabled,
+                                                   False)
         #cache settings
         try:
             QWebSettings.globalSettings().setAttribute(QWebSettings.LocalStorageEnabled,
@@ -182,7 +181,6 @@ class ViewMessage(MainWindow):
                     </b><br />") + text + "<br/>")
         """
         self.view_mes_widget.setHtml(code_html, QtCore.QUrl.fromLocalFile("."))
-        print code_html
         del(title)
         del(text)
         del(user)
@@ -219,7 +217,7 @@ class ViewMessage(MainWindow):
         file_tool_bar = ToolbarWindow(parent=self.centr_widg)
         file_tool_bar.addWidget(self.edit_act)
         file_tool_bar.addWidget(self.comment_act)
-        #file_tool_bar.addWidget(self.tree_act)
+        file_tool_bar.addWidget(self.tree_act)
         self.connect(file_tool_bar.home_act, QtCore.SIGNAL("clicked()"),
                              self.home_window)
         flag_our_post = False
@@ -228,7 +226,7 @@ class ViewMessage(MainWindow):
             if acc == our_acc:
                 flag_our_post = True
                 
-        #self.tree_act.setDisabled(not(flag_our_post))
+        self.tree_act.setDisabled(not(flag_our_post))
         
         if not self.msg.is_editable():
             self.edit_act.setDisabled(True)
@@ -308,13 +306,13 @@ class ViewMessage(MainWindow):
         self.connect(self.edit_act, QtCore.SIGNAL("clicked()"),
                      self.edit_post)
         
-        #self.tree_act = QtGui.QToolButton(self.centr_widg)
-        #self.tree_act.setIcon(QtGui.QIcon("../data/en/tree_comment.png"))
-        #self.tree_act.setText(self.tr("Comments"))
-        #self.tree_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
-        #self.tree_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
-        #self.connect(self.tree_act, QtCore.SIGNAL("clicked()"),
-         #            self.tree_comments)
+        self.tree_act = QtGui.QToolButton(self.centr_widg)
+        self.tree_act.setIcon(QtGui.QIcon("../data/en/tree_comment.png"))
+        self.tree_act.setText(self.tr("Comments"))
+        self.tree_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
+        self.tree_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
+        self.connect(self.tree_act, QtCore.SIGNAL("clicked()"),
+                     self.tree_comments)
         
 
     def view_prev_message(self):
@@ -417,13 +415,13 @@ class ViewMessage(MainWindow):
     
 
 
-    #def tree_comments(self):
+    def tree_comments(self):
         """
         window with tree message
         @param
         @return                                                      
         """
-       # tree_widg = TreeMessage(self, self.msg)
+        tree_widg = TreeMessage(self, self.msg)
     
 
 
